/*****************************************************************************
	FILE:	benchmark.c
	
	DESCRIPTION:
		Benchmark routines implementation in A.S.R.
		
	VERSION:
		Jun 14, 1999
******************************************************************************/

#include <sys/time.h>
#include <unistd.h>

struct timeval	tv1, tv2, dtv;
struct timezone	tz;

/*+ benchmark_start
PROTOTYPE:
	void benchmark_start(void);
	
DESCRIPTION:
	Runs a time counter for delay measurement.
	
PARAMETERS:
	none
	
RETURNS:
	nothing
-*/

void benchmark_start(void){	
	gettimeofday(&tv1, &tz);
} /* benchmark_start */

/*+ benchmark_stop
PROTOTYPE:
	long benchmark_stop(void);
	
DESCRIPTION:
	Stops the time counter for delay measurement.
	
PARAMETERS:
	none
	
RETURNS:
	number of milliseconds between start and stop counter calls.
-*/

long benchmark_stop(void){
	gettimeofday(&tv2, &tz);

	dtv.tv_sec	= tv2.tv_sec - tv1.tv_sec;
	dtv.tv_usec	= tv2.tv_usec - tv1.tv_usec;
	
	if(dtv.tv_usec < 0){
		dtv.tv_sec--;
		dtv.tv_usec += 1000000;
	}
	
	return dtv.tv_sec * 1000 + dtv.tv_usec / 1000;
} /* benchmark_stop */

/* end of file - benchmark.c */
